#
# spec file for package ncompress
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ncompress
Version:        4.2.4.4
Release:        lp150.17.1
Summary:        LZW compression and decompression utilities
License:        SUSE-Public-Domain
Group:          Productivity/Archiving/Compression
URL:            http://ncompress.sourceforge.net/
Source:         https://github.com/vapier/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         %{name}-4.2.4-make.patch
Patch1:         %{name}-4.2.4.4-lfs2.patch
Patch2:         %{name}-4.2.4.4-filenamelen.patch
Patch3:         %{name}-2GB.patch
Patch6:         %{name}-4.2.4-endians.patch
# PATCH-FIX-UPSTREAM -- drop date to fix build-compare (boo#1047218)
Patch7:         ncompress-4.2.4.4-drop-datestamp.patch
# gzip provides the uncompress tool in /usr/bin
# we don't provide a link here as this conflicts with gzip
Requires:       gzip

%description
The ncompress package contains the "compress" and "uncompress"
utilities which are compatible with the original UNIX compress
utility (.Z file extensions).

Install ncompress if you need compression/decompression utilities
which are compatible with the original UNIX compress utility. gzip is
also able to decompress .Z files, though ncompress will not recognize
.gz files at all.

%prep
%setup -q
%patch0 -p1
%patch1 -p1 -b .lfs
%patch2 -p1 -b .filenamelen
%patch3 -p1 -b .2GB
%patch6 -p1 -b .endians
%patch7 -p1

%build
export CFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE"
%ifarch sparc m68k armv4l ppc s390 s390x ppc64 sparc64
export ENDIAN=1234
%else
export ENDIAN=4321
%endif
make %{?_smp_mflags} Makefile # avoid build time race
make %{?_smp_mflags} ENDIAN="$ENDIAN"

%install
install -D -p -m 0755 compress \
  %{buildroot}%{_bindir}/compress
install -D -p -m 0644 compress.1 \
  %{buildroot}%{_mandir}/man1/compress.1

%files
%doc LZW.INFO README
%{_bindir}/compress
%{_mandir}/man1/compress.1%{?ext_man}

%changelog
* Thu Dec  6 2018 Martin Pluskal <mpluskal@suse.com>
- Really use optflags
* Sun Jul 23 2017 bwiedemann@suse.com
- Add ncompress-4.2.4.4-drop-datestamp.patch to drop compile date
  to fix build-compare (boo#1047218)
- Use make Makefile to avoid build time race
* Fri May 26 2017 jengelh@inai.de
- Reword description
* Sun May 21 2017 meissner@suse.com
- fixed endian define (bsc#1040046)
* Sun Oct 23 2016 mpluskal@suse.com
- Small spec file cleanups:
  * Use pretty name for archive
  * Drop alpha and itanium specific parts
  * Run spec-cleaner on spec file
* Thu Nov 26 2015 opensuse@dstoecker.de
- stop to provide uncompress tool and require gzip instead
* Wed Nov 11 2015 opensuse@dstoecker.de
- fix for Leap 42.1
* Sat Sep  8 2007 Dirk Stöcker <opensuse@dstoecker.de> 4.2.4
- adapted for openSUSE build service
  Sun Oct 01 2006 Jesse Keating 4.2.4
- rebuilt for unwind info generation, broken in gcc-4.1.1-21
  Tue Sep 19 2006 Peter Vrabec 4.2.4
- fix endian problem (#207001)
  Thu Aug 10 2006 Peter Vrabec 4.2.4
- fix bss buffer underflow CVE-2006-1168 (#201919)
  Fri Apr 21 2006 Peter Vrabec 4.2.4
- fix problems with compressing zero-sized files (#189215, #189216)
  Fri Feb 10 2006 Jesse Keating 4.2.4
- bump again for double-long bug on ppc(64)
  Tue Feb 07 2006 Jesse Keating 4.2.4
- rebuilt for new gcc4.1 snapshot and glibc changes
  Thu Sep 22 2005 Peter Vrabec 4.2.4
- compress zero-sized files when -f is used(#167615)
  Tue Oct 05 2004 Than Ngo 4.2.4
- permit files > 2GB to be compressed (#126775).
  Thu Dec 12 2002 Tim Powers 4.2.4
- rebuild on all arches
  Wed Jun 19 2002 Trond Eivind Glomsrød 4.2.4
- Don't strip when installing
  Mon Nov 26 2001 Trond Eivind Glomsrød 4.2.4
- Rebuild, to fix problem with broken man page (#56654)
  Wed Nov 21 2001 Trond Eivind Glomsrød 4.2.4
- Exit, don't segfault, when given too long filenames
  Sat Jun 09 2001 Florian La Roche 4.2.4
- s390x change
  Tue May  8 2001 Trond Eivind Glomsrød
- Make it support large files (structs, stats, opens and of course:
  _don't use signed longs for file size before and after compression_.)
  This should fix #39470
  Thu Apr 26 2001 Florian La Roche
- add s390x, patch from Oliver Paukstadt
  Mon Nov 13 2000 Oliver Paukstadt
- add s390 to the bigendian arch list
  Thu Aug 17 2000 Trond Eivind Glomsrød
- change category to Applications/File, to match
  gzip and bzip2
- rename the spec file to ncompress.spec
- add ppc to the bigendian arch list
  Tue Jun 13 2000 Trond Eivind Glomsrød
- update URL
- use %%%%{_mandir}
  Wed May  5 2000 Bill Nottingham
- fix build for ia64
  Mon Feb  7 2000 Bill Nottingham
- handle compressed manpages
  Sun Mar 21 1999 Cristian Gafton
- auto rebuild in the new build environment (release 14)
  Thu Aug 13 1998 Jeff Johnson
- build root
  Mon Apr 27 1998 Prospector System
- translations modified for de, fr, tr
  Wed Oct 21 1997 Cristian Gafton
- fixed the spec file
  Mon Jun 02 1997 Erik Troan
- built against glibc
